==> org.eclipse.scout.sdk.ui.source_3.9.2.20140206-1207.jar: org/eclipse/scout/sdk/ui/view/outline/IScoutExplorerPart.java <==
/*******************************************************************************
 * Copyright (c) 2010 BSI Business Systems Integration AG.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BSI Business Systems Integration AG - initial API and implementation
 ******************************************************************************/
package org.eclipse.scout.sdk.ui.view.outline;

import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.scout.sdk.ui.view.outline.pages.IPage;
import org.eclipse.ui.IWorkbenchPartSite;

/**
 * <h3>IScoutExplorerPart</h3>
 */
public interface IScoutExplorerPart {

  /**
   * Returns the site for this workbench part. The site can be <code>null</code> while the workbench part is being
   * initialized. After
   * the initialization is complete, this value must be non-<code>null</code> for the remainder of the part's life
   * cycle.
   * 
   * @return The part site; this value may be <code>null</code> if the part
   *         has not yet been initialized
   */
  IWorkbenchPartSite getSite();

  /**
   * gets the current selection of the scout explorer tree.
   * 
   * @return The structured selection of the tree.
   */
  IStructuredSelection getSelection();

  /**
   * sets the new selection of the scout explorer tree.
   * 
   * @param selection
   *          the new selection containing the {@link IPage} instances that should be selected.
   */
  void setSelection(IStructuredSelection selection);

  /**
   * expands the scout explorer tree to project level and sets the selection to the first project in the tree.
   */
  void expandAndSelectProjectLevel();

  /**
   * gets the (invisible) root page. this page contains the project nodes.
   * 
   * @return the invisible root page.
   */
  IPage getRootPage();
}

==> org.eclipse.scout.sdk.ui.source_4.0.0.20140505-1008.jar: org/eclipse/scout/sdk/ui/view/outline/IScoutExplorerPart.java <==
/*******************************************************************************
 * Copyright (c) 2010 BSI Business Systems Integration AG.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BSI Business Systems Integration AG - initial API and implementation
 ******************************************************************************/
package org.eclipse.scout.sdk.ui.view.outline;

import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.scout.sdk.ui.view.outline.pages.IPage;

/**
 * <h3>IScoutExplorerPart</h3>
 */
public interface IScoutExplorerPart extends IPageOutlineView, IDirtyManageable {
  /**
   * gets the current selection of the scout explorer tree.
   * 
   * @return The structured selection of the tree.
   */
  IStructuredSelection getSelection();

  /**
   * sets the new selection of the scout explorer tree.
   * 
   * @param selection
   *          the new selection containing the {@link IPage} instances that should be selected.
   */
  void setSelection(IStructuredSelection selection);

  /**
   * expands the scout explorer tree to project level and sets the selection to the first project in the tree.
   */
  void expandAndSelectProjectLevel();

  /**
   * gets the (invisible) root page. this page contains the project nodes.
   * 
   * @return the invisible root page.
   */
  IPage getRootPage();
}
